@@ -1348,7 +1348,7 @@ def explore_fit_mcmc(model_fitted, pars=[], hm_steps=7000, hm_walkers=2000, hm_j
 
     from astropy.table import Table
     flatchain= Table.from_pandas(explore.flatchain)
-    flatchain.write(stem+'.fits')
+    flatchain.write(stem+'.fits',overwrite=True)
 
     return explore, emcee_plot
 
